UI/SearchWidget.py

changeset 3366
6084bb3c3911
parent 3190
a9a94491c4fd
child 3484
645c12de6b0c
diff -r 5dafcc891579 -r 6084bb3c3911 UI/SearchWidget.py
--- a/UI/SearchWidget.py	Wed Mar 12 19:54:14 2014 +0100
+++ b/UI/SearchWidget.py	Thu Mar 13 19:21:25 2014 +0100
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing the search box for the shel, terminal and log viewer.
+Module implementing the search box for the shell, terminal and log viewer.
 """
 
 from PyQt4.QtCore import pyqtSlot, pyqtSignal, Qt
@@ -17,7 +17,7 @@
 
 class SearchWidget(QWidget, Ui_SearchWidget):
     """
     Class implementing the search box for the shel, terminal and log viewer.
     
     @signal searchNext(text, caseSensitive, wholeWord) emitted when the user
         pressed the next button (string, boolean, boolean)
@@ -60,6 +60,9 @@
         
         self.findtextCombo.lineEdit().returnPressed.connect(
             self.__findByReturnPressed)
+        
+        msh = self.minimumSizeHint()
+        self.resize(max(self.width(), msh.width()), msh.height())
     
     @pyqtSlot()
     def on_closeButton_clicked(self):
@@ -17,7 +17,7 @@
 class SearchWidget(QWidget, Ui_SearchWidget):
     """
-    Class implementing the search box for the shel, terminal and log viewer.
+    Class implementing the search box for the shell, terminal and log viewer.
     
     @signal searchNext(text, caseSensitive, wholeWord) emitted when the user

eric ide

mercurial